# Cammello <img src="https://raw.githubusercontent.com/LucaMingarelli/cammello/master/cammello/res/cammello.png"  width="80">

[![version](https://img.shields.io/badge/version-0.0.1-success.svg)](#)
[![PyPI Latest Release](https://img.shields.io/pypi/v/cammello.svg)](https://pypi.org/project/cammello/)
[![License](https://img.shields.io/pypi/l/cammello.svg)](https://github.com/LucaMingarelli/cammello/blob/master/LICENSE.txt)

[//]: # ([![Downloads]&#40;https://static.pepy.tech/personalized-badge/cammello?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads&#41;]&#40;https://pepy.tech/project/cammello&#41;)
